.. include:: ../BADGES.rst

Command Line
============

Help::

     tsgettoolbox –help

about
~~~~~
.. program-output:: tsgettoolbox about --help

cdec
~~~~
.. program-output:: tsgettoolbox cdec --help

coops
~~~~~
.. program-output:: tsgettoolbox coops --help

cpc
~~~
.. program-output:: tsgettoolbox cpc --help

daymet
~~~~~~
.. program-output:: tsgettoolbox daymet --help

epa_wqp
~~~~~~~
.. program-output:: tsgettoolbox epa_wqp --help

fawn
~~~~
.. program-output:: tsgettoolbox fawn --help

ldas
~~~~
.. program-output:: tsgettoolbox ldas --help

metdata
~~~~~~~
.. program-output:: tsgettoolbox metdata --help

modis
~~~~~
.. program-output:: tsgettoolbox modis --help

ncdc_annual
~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_annual --help

ncdc_ghcnd
~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_ghcnd --help

ncdc_ghcnd_ftp
~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_ghcnd_ftp --help

ncdc_ghcndms
~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_ghcndms --help

ncdc_gs
~~~~~~~
.. program-output:: tsgettoolbox ncdc_gs --help

ncdc_normal_ann
~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_normal_ann --help

ncdc_normal_dly
~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_normal_dly --help

ncdc_normal_hly
~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_normal_hly --help

ncdc_normal_mly
~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_normal_mly --help

ncdc_precip_15
~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_precip_15 --help

ncdc_precip_hly
~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox ncdc_precip_hly --help

ndbc
~~~~
.. program-output:: tsgettoolbox ndbc --help

nwis_dv
~~~~~~~
.. program-output:: tsgettoolbox nwis_dv --help

nwis_iv
~~~~~~~
.. program-output:: tsgettoolbox nwis_iv --help

nwis_site
~~~~~~~~~
.. program-output:: tsgettoolbox nwis_site --help

nwis_gwlevels
~~~~~~~~~~~~~
.. program-output:: tsgettoolbox nwis_gwlevels --help

nwis_measurements
~~~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox nwis_measurements --help

nwis_peak
~~~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox nwis_peak --help

nwis_stat
~~~~~~~~~~~~~~~~~
.. program-output:: tsgettoolbox nwis_stat --help

twc
~~~
.. program-output:: tsgettoolbox twc --help

unavco
~~~~~~
.. program-output:: tsgettoolbox unavco --help

usgs_eddn
~~~~~~~~~
.. program-output:: tsgettoolbox usgs_eddn --help
